@@ -120,7 +120,8 @@ class patient_dataset(Dataset):
     def no_mapping(cls, source0, source1):
         default_matching_name = 'id'
         sources = [source0, source1]
-        sources_mapping = [pd.DataFrame(source.index.values, columns=default_matching_name) for source in sources]
+        sources_mapping = [pd.DataFrame(source.index.values, columns=[default_matching_name], index=source.index)
+                           for source in sources]
         return cls(sources, sources_mapping, (default_matching_name, default_matching_name),
                    (default_matching_name, default_matching_name))
 
